@@ -34,18 +34,19 @@ where
             return;
         }
 
-        match e {
-            Expr::Unary(UnaryExpr {
-                op: op!("!"), arg, ..
-            }) => match &mut **arg {
+        if let Expr::Unary(UnaryExpr {
+            op: op!("!"), arg, ..
+        }) = e
+        {
+            match &mut **arg {
                 Expr::Bin(BinExpr {
                     op: op!("&&"),
                     left,
                     right,
                     ..
                 }) => {
-                    if negate_cost(&left, false, false).unwrap_or(isize::MAX) >= 0
-                        || negate_cost(&right, false, false).unwrap_or(isize::MAX) >= 0
+                    if negate_cost(left, false, false).unwrap_or(isize::MAX) >= 0
+                        || negate_cost(right, false, false).unwrap_or(isize::MAX) >= 0
                     {
                         return;
                     }
@@ -53,39 +54,33 @@ where
                     self.changed = true;
                     self.negate(arg, false, false);
                     *e = *arg.take();
-
-                    return;
                 }
 
                 Expr::Unary(UnaryExpr {
                     op: op!("!"),
                     arg: arg_of_arg,
                     ..
-                }) => match &mut **arg_of_arg {
-                    Expr::Bin(BinExpr {
+                }) => {
+                    if let Expr::Bin(BinExpr {
                         op: op!("||"),
                         left,
                         right,
                         ..
-                    }) => {
-                        if negate_cost(&left, false, false).unwrap_or(isize::MAX) > 0
-                            || negate_cost(&right, false, false).unwrap_or(isize::MAX) > 0
+                    }) = &mut **arg_of_arg
+                    {
+                        if negate_cost(left, false, false).unwrap_or(isize::MAX) > 0
+                            || negate_cost(right, false, false).unwrap_or(isize::MAX) > 0
                         {
                             return;
                         }
                         tracing::debug!("bools: Optimizing `!!(a || b)` as `!a && !b`");
                         self.negate(arg_of_arg, false, false);
                         *e = *arg.take();
-
-                        return;
                     }
-
-                    _ => {}
-                },
+                }
 
                 _ => {}
-            },
-            _ => {}
+            }
         }
     }
 
@@ -117,8 +112,8 @@ where
             _ => return,
         }
 
-        if should_optimize(&e.left, &e.right, &self.options)
-            || should_optimize(&e.right, &e.left, &self.options)
+        if should_optimize(&e.left, &e.right, self.options)
+            || should_optimize(&e.right, &e.left, self.options)
         {
             tracing::debug!("bools: Compressing comparison of `typeof` with literal");
             self.changed = true;
@@ -161,29 +156,25 @@ where
                 let lt = left.get_type();
                 let rt = right.get_type();
 
-                match (lt, rt) {
-                    (Value::Known(Type::Bool), Value::Known(Type::Bool)) => {
-                        let rb = right.as_pure_bool();
-                        let rb = match rb {
-                            Value::Known(v) => v,
-                            Value::Unknown => return,
-                        };
+                if let (Value::Known(Type::Bool), Value::Known(Type::Bool)) = (lt, rt) {
+                    let rb = right.as_pure_bool();
+                    let rb = match rb {
+                        Value::Known(v) => v,
+                        Value::Unknown => return,
+                    };
 
-                        //
-                        let can_remove = if *op == op!("&&") { rb } else { !rb };
+                    //
+                    let can_remove = if *op == op!("&&") { rb } else { !rb };
 
-                        if can_remove {
-                            if *op == op!("&&") {
-                                tracing::debug!("booleans: Compressing `!foo && true` as `!foo`");
-                            } else {
-                                tracing::debug!("booleans: Compressing `!foo || false` as `!foo`");
-                            }
-                            self.changed = true;
-                            *e = *left.take();
-                            return;
+                    if can_remove {
+                        if *op == op!("&&") {
+                            tracing::debug!("booleans: Compressing `!foo && true` as `!foo`");
+                        } else {
+                            tracing::debug!("booleans: Compressing `!foo || false` as `!foo`");
                         }
+                        self.changed = true;
+                        *e = *left.take();
                     }
-                    _ => {}
                 }
             }
             _ => {}
@@ -228,7 +219,7 @@ where
                 ..
             }) => false,
 
-            e if is_pure_undefined(&e) => true,
+            e if is_pure_undefined(e) => true,
 
             Expr::Ident(..) => true,
 
@@ -240,11 +231,7 @@ where
             }) => {
                 let rn = right.as_number();
                 let v = if let Value::Known(rn) = rn {
-                    if rn != 0.0 {
-                        true
-                    } else {
-                        false
-                    }
+                    rn != 0.0
                 } else {
                     false
                 };
@@ -271,7 +258,6 @@ where
             let span = delete.arg.span();
             tracing::debug!("booleans: Compressing `delete` => true");
             *e = make_bool(span, true);
-            return;
         }
     }
 
@@ -283,23 +269,20 @@ where
                     op: op!("delete"), ..
                 },
             ) => {
-                match &mut *e.arg {
-                    Expr::Seq(SeqExpr { exprs, .. }) => {
-                        if exprs.is_empty() {
-                            return;
-                        }
-                        tracing::debug!("bools: Optimizing negated sequences");
-
-                        {
-                            let last = exprs.last_mut().unwrap();
-                            self.optimize_expr_in_bool_ctx(last);
-                            // Negate last element.
-                            self.changed |= negate(last, false, false);
-                        }
-
-                        *n = *e.arg.take();
+                if let Expr::Seq(SeqExpr { exprs, .. }) = &mut *e.arg {
+                    if exprs.is_empty() {
+                        return;
                     }
-                    _ => {}
+                    tracing::debug!("bools: Optimizing negated sequences");
+
+                    {
+                        let last = exprs.last_mut().unwrap();
+                        self.optimize_expr_in_bool_ctx(last);
+                        // Negate last element.
+                        self.changed |= negate(last, false, false);
+                    }
+
+                    *n = *e.arg.take();
                 }
             }
             _ => {}
@@ -357,7 +340,6 @@ where
                     tracing::debug!("bools: !!expr => expr (in bool ctx)");
                     self.changed = true;
                     *n = *arg.take();
-                    return;
                 }
                 _ => {}
             },
@@ -442,7 +424,6 @@ where
                     tracing::debug!("bools: `expr || false` => `expr` (in bool context)");
                     self.changed = true;
                     *n = *left.take();
-                    return;
                 }
             }
 
@@ -452,7 +433,6 @@ where
                 if let Value::Known(v) = v {
                     tracing::debug!("Optimizing expr as {} (in bool context)", v);
                     *n = make_bool(span, v);
-                    return;
                 }
             }
         }
@@ -483,13 +463,7 @@ where
                 Expr::Unary(UnaryExpr {
                     op: op!("!"), arg, ..
                 }),
-            ) if match &**arg {
-                Expr::Lit(..) => true,
-                _ => false,
-            } =>
-            {
-                true
-            }
+            ) if matches!(&**arg, Expr::Lit(..)) => true,
 
             (Expr::Member(..) | Expr::Call(..) | Expr::Assign(..), r) if is_pure_undefined(r) => {
                 true
@@ -521,24 +495,24 @@ where
 
     fn try_swap_bin(&mut self, op: BinaryOp, left: &mut Expr, right: &mut Expr) -> bool {
         fn is_supported(op: BinaryOp) -> bool {
-            match op {
+            matches!(
+                op,
                 op!("===")
-                | op!("!==")
-                | op!("==")
-                | op!("!=")
-                | op!("&")
-                | op!("^")
-                | op!("|")
-                | op!("*") => true,
-                _ => false,
-            }
+                    | op!("!==")
+                    | op!("==")
+                    | op!("!=")
+                    | op!("&")
+                    | op!("^")
+                    | op!("|")
+                    | op!("*")
+            )
         }
 
         if !is_supported(op) {
             return false;
         }
 
-        if self.can_swap_bin_operands(&left, &right, false) {
+        if self.can_swap_bin_operands(left, right, false) {
             tracing::debug!("Swapping operands of binary expession");
             swap(left, right);
             return true;
@@ -672,23 +646,19 @@ where
                 }
             }
 
-            match (&mut *e.left, &mut *e.right) {
-                (Expr::Bin(left), right) => {
-                    if e.op == left.op {
-                        let res = opt(right.span(), e.op, &mut left.right, &mut *right);
-                        if let Some(res) = res {
-                            self.changed = true;
-                            *e = BinExpr {
-                                span: e.span,
-                                op: e.op,
-                                left: left.left.take(),
-                                right: Box::new(Expr::Bin(res)),
-                            };
-                            return;
-                        }
+            if let (Expr::Bin(left), right) = (&mut *e.left, &mut *e.right) {
+                if e.op == left.op {
+                    let res = opt(right.span(), e.op, &mut left.right, &mut *right);
+                    if let Some(res) = res {
+                        self.changed = true;
+                        *e = BinExpr {
+                            span: e.span,
+                            op: e.op,
+                            left: left.left.take(),
+                            right: Box::new(Expr::Bin(res)),
+                        };
                     }
                 }
-                _ => {}
             }
         }
     }
